# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class AssetGroupTreeOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'children': 'list[AssetGroupTreeOutputV1]',
        'datasource_id': 'str',
        'description': 'str',
        'item': 'ItemPreviewWithAssetsV1',
        'parameters': 'list[FormulaParameterOutputV1]'
    }

    attribute_map = {
        'children': 'children',
        'datasource_id': 'datasourceId',
        'description': 'description',
        'item': 'item',
        'parameters': 'parameters'
    }

    def __init__(self, children=None, datasource_id=None, description=None, item=None, parameters=None):
        """
        AssetGroupTreeOutputV1 - a model defined in Swagger
        """

        self._children = None
        self._datasource_id = None
        self._description = None
        self._item = None
        self._parameters = None

        if children is not None:
          self.children = children
        if datasource_id is not None:
          self.datasource_id = datasource_id
        if description is not None:
          self.description = description
        if item is not None:
          self.item = item
        if parameters is not None:
          self.parameters = parameters

    @property
    def children(self):
        """
        Gets the children of this AssetGroupTreeOutputV1.
        The list of the tree node's children

        :return: The children of this AssetGroupTreeOutputV1.
        :rtype: list[AssetGroupTreeOutputV1]
        """
        return self._children

    @children.setter
    def children(self, children):
        """
        Sets the children of this AssetGroupTreeOutputV1.
        The list of the tree node's children

        :param children: The children of this AssetGroupTreeOutputV1.
        :type: list[AssetGroupTreeOutputV1]
        """

        self._children = children

    @property
    def datasource_id(self):
        """
        Gets the datasource_id of this AssetGroupTreeOutputV1.
        The datasource id of the tree node

        :return: The datasource_id of this AssetGroupTreeOutputV1.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """
        Sets the datasource_id of this AssetGroupTreeOutputV1.
        The datasource id of the tree node

        :param datasource_id: The datasource_id of this AssetGroupTreeOutputV1.
        :type: str
        """

        self._datasource_id = datasource_id

    @property
    def description(self):
        """
        Gets the description of this AssetGroupTreeOutputV1.
        A description of the tree node

        :return: The description of this AssetGroupTreeOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AssetGroupTreeOutputV1.
        A description of the tree node

        :param description: The description of this AssetGroupTreeOutputV1.
        :type: str
        """

        self._description = description

    @property
    def item(self):
        """
        Gets the item of this AssetGroupTreeOutputV1.

        :return: The item of this AssetGroupTreeOutputV1.
        :rtype: ItemPreviewWithAssetsV1
        """
        return self._item

    @item.setter
    def item(self, item):
        """
        Sets the item of this AssetGroupTreeOutputV1.

        :param item: The item of this AssetGroupTreeOutputV1.
        :type: ItemPreviewWithAssetsV1
        """

        self._item = item

    @property
    def parameters(self):
        """
        Gets the parameters of this AssetGroupTreeOutputV1.
        Formula Parameters used to create the formula

        :return: The parameters of this AssetGroupTreeOutputV1.
        :rtype: list[FormulaParameterOutputV1]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this AssetGroupTreeOutputV1.
        Formula Parameters used to create the formula

        :param parameters: The parameters of this AssetGroupTreeOutputV1.
        :type: list[FormulaParameterOutputV1]
        """

        self._parameters = parameters

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AssetGroupTreeOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

__version__ = "62.0.10"

# import apis into sdk package
from .access_keys_api import AccessKeysApi
from .add_ons_api import AddOnsApi
from .agents_api import AgentsApi
from .annotations_api import AnnotationsApi
from .assets_api import AssetsApi
from .audit_api import AuditApi
from .auth_api import AuthApi
from .condition_monitors_api import ConditionMonitorsApi
from .conditions_api import ConditionsApi
from .content_api import ContentApi
from .context_api import ContextApi
from .datafiles_api import DatafilesApi
from .datasources_api import DatasourcesApi
from .display_templates_api import DisplayTemplatesApi
from .displays_api import DisplaysApi
from .export_api import ExportApi
from .folders_api import FoldersApi
from .formulas_api import FormulasApi
from .graph_ql_api import GraphQLApi
from .items_api import ItemsApi
from .jobs_api import JobsApi
from .logs_api import LogsApi
from .metrics_api import MetricsApi
from .monitors_api import MonitorsApi
from .networks_api import NetworksApi
from .notification_configurations_api import NotificationConfigurationsApi
from .notifier_api import NotifierApi
from .plugins_api import PluginsApi
from .projects_api import ProjectsApi
from .report_templates_api import ReportTemplatesApi
from .reports_api import ReportsApi
from .requests_api import RequestsApi
from .scalars_api import ScalarsApi
from .signals_api import SignalsApi
from .subscriptions_api import SubscriptionsApi
from .system_api import SystemApi
from .table_definitions_api import TableDefinitionsApi
from .trees_api import TreesApi
from .usage_api import UsageApi
from .user_groups_api import UserGroupsApi
from .users_api import UsersApi
from .workbooks_api import WorkbooksApi



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ScheduledNotebookOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'average_run_time': 'int',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'enabled': 'bool',
        'file_path': 'str',
        'id': 'str',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'label': 'str',
        'name': 'str',
        'project': 'ItemPreviewV1',
        'run_user': 'IdentityPreviewV1',
        'schedules': 'list[ScheduleOutputV1]',
        'status_message': 'str',
        'timezone': 'str',
        'total_run_time': 'int',
        'translation_key': 'str',
        'type': 'str'
    }

    attribute_map = {
        'average_run_time': 'averageRunTime',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'enabled': 'enabled',
        'file_path': 'filePath',
        'id': 'id',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'label': 'label',
        'name': 'name',
        'project': 'project',
        'run_user': 'runUser',
        'schedules': 'schedules',
        'status_message': 'statusMessage',
        'timezone': 'timezone',
        'total_run_time': 'totalRunTime',
        'translation_key': 'translationKey',
        'type': 'type'
    }

    def __init__(self, average_run_time=None, description=None, effective_permissions=None, enabled=True, file_path=None, id=None, is_archived=False, is_redacted=False, label=None, name=None, project=None, run_user=None, schedules=None, status_message=None, timezone=None, total_run_time=None, translation_key=None, type=None):
        """
        ScheduledNotebookOutputV1 - a model defined in Swagger
        """

        self._average_run_time = None
        self._description = None
        self._effective_permissions = None
        self._enabled = None
        self._file_path = None
        self._id = None
        self._is_archived = None
        self._is_redacted = None
        self._label = None
        self._name = None
        self._project = None
        self._run_user = None
        self._schedules = None
        self._status_message = None
        self._timezone = None
        self._total_run_time = None
        self._translation_key = None
        self._type = None

        if average_run_time is not None:
          self.average_run_time = average_run_time
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if enabled is not None:
          self.enabled = enabled
        if file_path is not None:
          self.file_path = file_path
        if id is not None:
          self.id = id
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if label is not None:
          self.label = label
        if name is not None:
          self.name = name
        if project is not None:
          self.project = project
        if run_user is not None:
          self.run_user = run_user
        if schedules is not None:
          self.schedules = schedules
        if status_message is not None:
          self.status_message = status_message
        if timezone is not None:
          self.timezone = timezone
        if total_run_time is not None:
          self.total_run_time = total_run_time
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type

    @property
    def average_run_time(self):
        """
        Gets the average_run_time of this ScheduledNotebookOutputV1.
        The average run time of the Notebook, in ms

        :return: The average_run_time of this ScheduledNotebookOutputV1.
        :rtype: int
        """
        return self._average_run_time

    @average_run_time.setter
    def average_run_time(self, average_run_time):
        """
        Sets the average_run_time of this ScheduledNotebookOutputV1.
        The average run time of the Notebook, in ms

        :param average_run_time: The average_run_time of this ScheduledNotebookOutputV1.
        :type: int
        """

        self._average_run_time = average_run_time

    @property
    def description(self):
        """
        Gets the description of this ScheduledNotebookOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this ScheduledNotebookOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ScheduledNotebookOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this ScheduledNotebookOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this ScheduledNotebookOutputV1.

        :return: The effective_permissions of this ScheduledNotebookOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this ScheduledNotebookOutputV1.

        :param effective_permissions: The effective_permissions of this ScheduledNotebookOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def enabled(self):
        """
        Gets the enabled of this ScheduledNotebookOutputV1.
        Whether the schedule is enabled to run jobs

        :return: The enabled of this ScheduledNotebookOutputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ScheduledNotebookOutputV1.
        Whether the schedule is enabled to run jobs

        :param enabled: The enabled of this ScheduledNotebookOutputV1.
        :type: bool
        """

        self._enabled = enabled

    @property
    def file_path(self):
        """
        Gets the file_path of this ScheduledNotebookOutputV1.
        The path to the ipynb file to be run

        :return: The file_path of this ScheduledNotebookOutputV1.
        :rtype: str
        """
        return self._file_path

    @file_path.setter
    def file_path(self, file_path):
        """
        Sets the file_path of this ScheduledNotebookOutputV1.
        The path to the ipynb file to be run

        :param file_path: The file_path of this ScheduledNotebookOutputV1.
        :type: str
        """

        self._file_path = file_path

    @property
    def id(self):
        """
        Gets the id of this ScheduledNotebookOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this ScheduledNotebookOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScheduledNotebookOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this ScheduledNotebookOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this ScheduledNotebookOutputV1.
        Whether item is archived

        :return: The is_archived of this ScheduledNotebookOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this ScheduledNotebookOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this ScheduledNotebookOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this ScheduledNotebookOutputV1.
        Whether item is redacted

        :return: The is_redacted of this ScheduledNotebookOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this ScheduledNotebookOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this ScheduledNotebookOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def label(self):
        """
        Gets the label of this ScheduledNotebookOutputV1.
        The label to distinguish different schedules of a given Notebook filePath

        :return: The label of this ScheduledNotebookOutputV1.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this ScheduledNotebookOutputV1.
        The label to distinguish different schedules of a given Notebook filePath

        :param label: The label of this ScheduledNotebookOutputV1.
        :type: str
        """

        self._label = label

    @property
    def name(self):
        """
        Gets the name of this ScheduledNotebookOutputV1.
        The human readable name

        :return: The name of this ScheduledNotebookOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ScheduledNotebookOutputV1.
        The human readable name

        :param name: The name of this ScheduledNotebookOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def project(self):
        """
        Gets the project of this ScheduledNotebookOutputV1.

        :return: The project of this ScheduledNotebookOutputV1.
        :rtype: ItemPreviewV1
        """
        return self._project

    @project.setter
    def project(self, project):
        """
        Sets the project of this ScheduledNotebookOutputV1.

        :param project: The project of this ScheduledNotebookOutputV1.
        :type: ItemPreviewV1
        """

        self._project = project

    @property
    def run_user(self):
        """
        Gets the run_user of this ScheduledNotebookOutputV1.

        :return: The run_user of this ScheduledNotebookOutputV1.
        :rtype: IdentityPreviewV1
        """
        return self._run_user

    @run_user.setter
    def run_user(self, run_user):
        """
        Sets the run_user of this ScheduledNotebookOutputV1.

        :param run_user: The run_user of this ScheduledNotebookOutputV1.
        :type: IdentityPreviewV1
        """

        self._run_user = run_user

    @property
    def schedules(self):
        """
        Gets the schedules of this ScheduledNotebookOutputV1.
        The run schedule for the Notebook-label combination

        :return: The schedules of this ScheduledNotebookOutputV1.
        :rtype: list[ScheduleOutputV1]
        """
        return self._schedules

    @schedules.setter
    def schedules(self, schedules):
        """
        Sets the schedules of this ScheduledNotebookOutputV1.
        The run schedule for the Notebook-label combination

        :param schedules: The schedules of this ScheduledNotebookOutputV1.
        :type: list[ScheduleOutputV1]
        """

        self._schedules = schedules

    @property
    def status_message(self):
        """
        Gets the status_message of this ScheduledNotebookOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this ScheduledNotebookOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this ScheduledNotebookOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this ScheduledNotebookOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def timezone(self):
        """
        Gets the timezone of this ScheduledNotebookOutputV1.
        The IANA time zone name in which the schedule will be run

        :return: The timezone of this ScheduledNotebookOutputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this ScheduledNotebookOutputV1.
        The IANA time zone name in which the schedule will be run

        :param timezone: The timezone of this ScheduledNotebookOutputV1.
        :type: str
        """

        self._timezone = timezone

    @property
    def total_run_time(self):
        """
        Gets the total_run_time of this ScheduledNotebookOutputV1.
        The total run time of the Notebook, in ms

        :return: The total_run_time of this ScheduledNotebookOutputV1.
        :rtype: int
        """
        return self._total_run_time

    @total_run_time.setter
    def total_run_time(self, total_run_time):
        """
        Sets the total_run_time of this ScheduledNotebookOutputV1.
        The total run time of the Notebook, in ms

        :param total_run_time: The total_run_time of this ScheduledNotebookOutputV1.
        :type: int
        """

        self._total_run_time = total_run_time

    @property
    def translation_key(self):
        """
        Gets the translation_key of this ScheduledNotebookOutputV1.
        The item's translation key, if any

        :return: The translation_key of this ScheduledNotebookOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this ScheduledNotebookOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this ScheduledNotebookOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this ScheduledNotebookOutputV1.
        The type of the item

        :return: The type of this ScheduledNotebookOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ScheduledNotebookOutputV1.
        The type of the item

        :param type: The type of this ScheduledNotebookOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ScheduledNotebookOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ContextOutputListV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comments': 'list[ContextCommentOutputV1]',
        'labels': 'list[ContextLabelOutputV1]',
        'opaque': 'list[ContextOpaqueOutputV1]',
        'total_results': 'int'
    }

    attribute_map = {
        'comments': 'comments',
        'labels': 'labels',
        'opaque': 'opaque',
        'total_results': 'totalResults'
    }

    def __init__(self, comments=None, labels=None, opaque=None, total_results=None):
        """
        ContextOutputListV1 - a model defined in Swagger
        """

        self._comments = None
        self._labels = None
        self._opaque = None
        self._total_results = None

        if comments is not None:
          self.comments = comments
        if labels is not None:
          self.labels = labels
        if opaque is not None:
          self.opaque = opaque
        if total_results is not None:
          self.total_results = total_results

    @property
    def comments(self):
        """
        Gets the comments of this ContextOutputListV1.
        A list of comments

        :return: The comments of this ContextOutputListV1.
        :rtype: list[ContextCommentOutputV1]
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """
        Sets the comments of this ContextOutputListV1.
        A list of comments

        :param comments: The comments of this ContextOutputListV1.
        :type: list[ContextCommentOutputV1]
        """
        if comments is None:
            raise ValueError("Invalid value for `comments`, must not be `None`")

        self._comments = comments

    @property
    def labels(self):
        """
        Gets the labels of this ContextOutputListV1.
        A list of labels

        :return: The labels of this ContextOutputListV1.
        :rtype: list[ContextLabelOutputV1]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """
        Sets the labels of this ContextOutputListV1.
        A list of labels

        :param labels: The labels of this ContextOutputListV1.
        :type: list[ContextLabelOutputV1]
        """
        if labels is None:
            raise ValueError("Invalid value for `labels`, must not be `None`")

        self._labels = labels

    @property
    def opaque(self):
        """
        Gets the opaque of this ContextOutputListV1.
        A list of opaque context

        :return: The opaque of this ContextOutputListV1.
        :rtype: list[ContextOpaqueOutputV1]
        """
        return self._opaque

    @opaque.setter
    def opaque(self, opaque):
        """
        Sets the opaque of this ContextOutputListV1.
        A list of opaque context

        :param opaque: The opaque of this ContextOutputListV1.
        :type: list[ContextOpaqueOutputV1]
        """
        if opaque is None:
            raise ValueError("Invalid value for `opaque`, must not be `None`")

        self._opaque = opaque

    @property
    def total_results(self):
        """
        Gets the total_results of this ContextOutputListV1.
        The total number of context

        :return: The total_results of this ContextOutputListV1.
        :rtype: int
        """
        return self._total_results

    @total_results.setter
    def total_results(self, total_results):
        """
        Sets the total_results of this ContextOutputListV1.
        The total number of context

        :param total_results: The total_results of this ContextOutputListV1.
        :type: int
        """
        if total_results is None:
            raise ValueError("Invalid value for `total_results`, must not be `None`")

        self._total_results = total_results

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ContextOutputListV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConnectionStatusOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'agent_name': 'str',
        'connection_id': 'str',
        'connection_message': 'str',
        'connector_developer_name': 'str',
        'connector_developer_support_url': 'str',
        'connector_name': 'str',
        'created_at': 'str',
        'datasource_managed': 'bool',
        'disabled_at': 'str',
        'disabled_by': 'str',
        'has_error': 'bool',
        'last_successful_connected_at': 'str',
        'name': 'str',
        'status': 'str',
        'sync_status': 'str'
    }

    attribute_map = {
        'agent_name': 'agentName',
        'connection_id': 'connectionId',
        'connection_message': 'connectionMessage',
        'connector_developer_name': 'connectorDeveloperName',
        'connector_developer_support_url': 'connectorDeveloperSupportUrl',
        'connector_name': 'connectorName',
        'created_at': 'createdAt',
        'datasource_managed': 'datasourceManaged',
        'disabled_at': 'disabledAt',
        'disabled_by': 'disabledBy',
        'has_error': 'hasError',
        'last_successful_connected_at': 'lastSuccessfulConnectedAt',
        'name': 'name',
        'status': 'status',
        'sync_status': 'syncStatus'
    }

    def __init__(self, agent_name=None, connection_id=None, connection_message=None, connector_developer_name=None, connector_developer_support_url=None, connector_name=None, created_at=None, datasource_managed=False, disabled_at=None, disabled_by=None, has_error=False, last_successful_connected_at=None, name=None, status=None, sync_status=None):
        """
        ConnectionStatusOutputV1 - a model defined in Swagger
        """

        self._agent_name = None
        self._connection_id = None
        self._connection_message = None
        self._connector_developer_name = None
        self._connector_developer_support_url = None
        self._connector_name = None
        self._created_at = None
        self._datasource_managed = None
        self._disabled_at = None
        self._disabled_by = None
        self._has_error = None
        self._last_successful_connected_at = None
        self._name = None
        self._status = None
        self._sync_status = None

        if agent_name is not None:
          self.agent_name = agent_name
        if connection_id is not None:
          self.connection_id = connection_id
        if connection_message is not None:
          self.connection_message = connection_message
        if connector_developer_name is not None:
          self.connector_developer_name = connector_developer_name
        if connector_developer_support_url is not None:
          self.connector_developer_support_url = connector_developer_support_url
        if connector_name is not None:
          self.connector_name = connector_name
        if created_at is not None:
          self.created_at = created_at
        if datasource_managed is not None:
          self.datasource_managed = datasource_managed
        if disabled_at is not None:
          self.disabled_at = disabled_at
        if disabled_by is not None:
          self.disabled_by = disabled_by
        if has_error is not None:
          self.has_error = has_error
        if last_successful_connected_at is not None:
          self.last_successful_connected_at = last_successful_connected_at
        if name is not None:
          self.name = name
        if status is not None:
          self.status = status
        if sync_status is not None:
          self.sync_status = sync_status

    @property
    def agent_name(self):
        """
        Gets the agent_name of this ConnectionStatusOutputV1.
        The name identifying the agent where the connector is hosted

        :return: The agent_name of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._agent_name

    @agent_name.setter
    def agent_name(self, agent_name):
        """
        Sets the agent_name of this ConnectionStatusOutputV1.
        The name identifying the agent where the connector is hosted

        :param agent_name: The agent_name of this ConnectionStatusOutputV1.
        :type: str
        """
        if agent_name is None:
            raise ValueError("Invalid value for `agent_name`, must not be `None`")

        self._agent_name = agent_name

    @property
    def connection_id(self):
        """
        Gets the connection_id of this ConnectionStatusOutputV1.
        The connectionID of the connection. This ID uniquely identifies this connection but it would not necessary be in the form of an UUID

        :return: The connection_id of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """
        Sets the connection_id of this ConnectionStatusOutputV1.
        The connectionID of the connection. This ID uniquely identifies this connection but it would not necessary be in the form of an UUID

        :param connection_id: The connection_id of this ConnectionStatusOutputV1.
        :type: str
        """
        if connection_id is None:
            raise ValueError("Invalid value for `connection_id`, must not be `None`")

        self._connection_id = connection_id

    @property
    def connection_message(self):
        """
        Gets the connection_message of this ConnectionStatusOutputV1.
        The message indicating the status of the connection to the datasource (e.g. reason for disconnection)

        :return: The connection_message of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._connection_message

    @connection_message.setter
    def connection_message(self, connection_message):
        """
        Sets the connection_message of this ConnectionStatusOutputV1.
        The message indicating the status of the connection to the datasource (e.g. reason for disconnection)

        :param connection_message: The connection_message of this ConnectionStatusOutputV1.
        :type: str
        """

        self._connection_message = connection_message

    @property
    def connector_developer_name(self):
        """
        Gets the connector_developer_name of this ConnectionStatusOutputV1.
        The name of this datasource's connector developer.

        :return: The connector_developer_name of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._connector_developer_name

    @connector_developer_name.setter
    def connector_developer_name(self, connector_developer_name):
        """
        Sets the connector_developer_name of this ConnectionStatusOutputV1.
        The name of this datasource's connector developer.

        :param connector_developer_name: The connector_developer_name of this ConnectionStatusOutputV1.
        :type: str
        """

        self._connector_developer_name = connector_developer_name

    @property
    def connector_developer_support_url(self):
        """
        Gets the connector_developer_support_url of this ConnectionStatusOutputV1.
        The support URL of this datasource's connector developer.

        :return: The connector_developer_support_url of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._connector_developer_support_url

    @connector_developer_support_url.setter
    def connector_developer_support_url(self, connector_developer_support_url):
        """
        Sets the connector_developer_support_url of this ConnectionStatusOutputV1.
        The support URL of this datasource's connector developer.

        :param connector_developer_support_url: The connector_developer_support_url of this ConnectionStatusOutputV1.
        :type: str
        """

        self._connector_developer_support_url = connector_developer_support_url

    @property
    def connector_name(self):
        """
        Gets the connector_name of this ConnectionStatusOutputV1.
        The name identifying the connector

        :return: The connector_name of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._connector_name

    @connector_name.setter
    def connector_name(self, connector_name):
        """
        Sets the connector_name of this ConnectionStatusOutputV1.
        The name identifying the connector

        :param connector_name: The connector_name of this ConnectionStatusOutputV1.
        :type: str
        """

        self._connector_name = connector_name

    @property
    def created_at(self):
        """
        Gets the created_at of this ConnectionStatusOutputV1.
        The timestamp of the connection creation

        :return: The created_at of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this ConnectionStatusOutputV1.
        The timestamp of the connection creation

        :param created_at: The created_at of this ConnectionStatusOutputV1.
        :type: str
        """

        self._created_at = created_at

    @property
    def datasource_managed(self):
        """
        Gets the datasource_managed of this ConnectionStatusOutputV1.
        Indicates if the configuration is managed by the datasource and cannot be changed in Seeq

        :return: The datasource_managed of this ConnectionStatusOutputV1.
        :rtype: bool
        """
        return self._datasource_managed

    @datasource_managed.setter
    def datasource_managed(self, datasource_managed):
        """
        Sets the datasource_managed of this ConnectionStatusOutputV1.
        Indicates if the configuration is managed by the datasource and cannot be changed in Seeq

        :param datasource_managed: The datasource_managed of this ConnectionStatusOutputV1.
        :type: bool
        """

        self._datasource_managed = datasource_managed

    @property
    def disabled_at(self):
        """
        Gets the disabled_at of this ConnectionStatusOutputV1.
        The ISO 8601 date of when the connection was disabled (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The disabled_at of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._disabled_at

    @disabled_at.setter
    def disabled_at(self, disabled_at):
        """
        Sets the disabled_at of this ConnectionStatusOutputV1.
        The ISO 8601 date of when the connection was disabled (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param disabled_at: The disabled_at of this ConnectionStatusOutputV1.
        :type: str
        """

        self._disabled_at = disabled_at

    @property
    def disabled_by(self):
        """
        Gets the disabled_by of this ConnectionStatusOutputV1.
        The username of the user who disabled the connection

        :return: The disabled_by of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._disabled_by

    @disabled_by.setter
    def disabled_by(self, disabled_by):
        """
        Sets the disabled_by of this ConnectionStatusOutputV1.
        The username of the user who disabled the connection

        :param disabled_by: The disabled_by of this ConnectionStatusOutputV1.
        :type: str
        """

        self._disabled_by = disabled_by

    @property
    def has_error(self):
        """
        Gets the has_error of this ConnectionStatusOutputV1.
        Indicates if the connection has an error

        :return: The has_error of this ConnectionStatusOutputV1.
        :rtype: bool
        """
        return self._has_error

    @has_error.setter
    def has_error(self, has_error):
        """
        Sets the has_error of this ConnectionStatusOutputV1.
        Indicates if the connection has an error

        :param has_error: The has_error of this ConnectionStatusOutputV1.
        :type: bool
        """

        self._has_error = has_error

    @property
    def last_successful_connected_at(self):
        """
        Gets the last_successful_connected_at of this ConnectionStatusOutputV1.
        The ISO 8601 date of the last successful connection to the external datasource (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The last_successful_connected_at of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._last_successful_connected_at

    @last_successful_connected_at.setter
    def last_successful_connected_at(self, last_successful_connected_at):
        """
        Sets the last_successful_connected_at of this ConnectionStatusOutputV1.
        The ISO 8601 date of the last successful connection to the external datasource (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param last_successful_connected_at: The last_successful_connected_at of this ConnectionStatusOutputV1.
        :type: str
        """

        self._last_successful_connected_at = last_successful_connected_at

    @property
    def name(self):
        """
        Gets the name of this ConnectionStatusOutputV1.
        The name of this connection. The name should represent the specific data source to which this connection connects.  Example: AMAZONA-4RV912N

        :return: The name of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConnectionStatusOutputV1.
        The name of this connection. The name should represent the specific data source to which this connection connects.  Example: AMAZONA-4RV912N

        :param name: The name of this ConnectionStatusOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def status(self):
        """
        Gets the status of this ConnectionStatusOutputV1.
        The status of the current connection between the datasource and the connector. Valid values are CONNECTING, CONNECTED, DISCONNECTED and DISABLED. If the state is DISCONNECTED (or CONNECTING), it could be caused by a failure in the connection between the connector and its datasource or a failed connection between the Seeq application server and the agent hosting this connector. See connectionMessage.

        :return: The status of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ConnectionStatusOutputV1.
        The status of the current connection between the datasource and the connector. Valid values are CONNECTING, CONNECTED, DISCONNECTED and DISABLED. If the state is DISCONNECTED (or CONNECTING), it could be caused by a failure in the connection between the connector and its datasource or a failed connection between the Seeq application server and the agent hosting this connector. See connectionMessage.

        :param status: The status of this ConnectionStatusOutputV1.
        :type: str
        """

        self._status = status

    @property
    def sync_status(self):
        """
        Gets the sync_status of this ConnectionStatusOutputV1.
        The synchronization status of the current connection between the datasource and this connector. Valid values are SYNC_UNKNOWN, SYNC_INITIALIZING, SYNC_IN_PROGRESS, SYNC_ARCHIVING_DELETED_ITEMS, SYNC_COMPLETE, SYNC_SUCCESS, SYNC_FAILED

        :return: The sync_status of this ConnectionStatusOutputV1.
        :rtype: str
        """
        return self._sync_status

    @sync_status.setter
    def sync_status(self, sync_status):
        """
        Sets the sync_status of this ConnectionStatusOutputV1.
        The synchronization status of the current connection between the datasource and this connector. Valid values are SYNC_UNKNOWN, SYNC_INITIALIZING, SYNC_IN_PROGRESS, SYNC_ARCHIVING_DELETED_ITEMS, SYNC_COMPLETE, SYNC_SUCCESS, SYNC_FAILED

        :param sync_status: The sync_status of this ConnectionStatusOutputV1.
        :type: str
        """
        allowed_values = ["SYNC_ARCHIVING_DELETED_ITEMS", "SYNC_IN_PROGRESS", "SYNC_INITIALIZING", "SYNC_SUCCESS", "SYNC_COMPLETE", "SYNC_FAILED", "SYNC_UNKNOWN"]
        if sync_status not in allowed_values:
            raise ValueError(
                "Invalid value for `sync_status` ({0}), must be one of {1}"
                .format(sync_status, allowed_values)
            )

        self._sync_status = sync_status

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConnectionStatusOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class AssetSelectionInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'archived': 'bool',
        'asset_id': 'str',
        'asset_path_depth': 'int',
        'description': 'str',
        'name': 'str',
        'report_id': 'str',
        'selection_id': 'str'
    }

    attribute_map = {
        'archived': 'archived',
        'asset_id': 'assetId',
        'asset_path_depth': 'assetPathDepth',
        'description': 'description',
        'name': 'name',
        'report_id': 'reportId',
        'selection_id': 'selectionId'
    }

    def __init__(self, archived=False, asset_id=None, asset_path_depth=None, description=None, name=None, report_id=None, selection_id=None):
        """
        AssetSelectionInputV1 - a model defined in Swagger
        """

        self._archived = None
        self._asset_id = None
        self._asset_path_depth = None
        self._description = None
        self._name = None
        self._report_id = None
        self._selection_id = None

        if archived is not None:
          self.archived = archived
        if asset_id is not None:
          self.asset_id = asset_id
        if asset_path_depth is not None:
          self.asset_path_depth = asset_path_depth
        if description is not None:
          self.description = description
        if name is not None:
          self.name = name
        if report_id is not None:
          self.report_id = report_id
        if selection_id is not None:
          self.selection_id = selection_id

    @property
    def archived(self):
        """
        Gets the archived of this AssetSelectionInputV1.
        Whether the assetSelection should be archived

        :return: The archived of this AssetSelectionInputV1.
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """
        Sets the archived of this AssetSelectionInputV1.
        Whether the assetSelection should be archived

        :param archived: The archived of this AssetSelectionInputV1.
        :type: bool
        """

        self._archived = archived

    @property
    def asset_id(self):
        """
        Gets the asset_id of this AssetSelectionInputV1.
        The asset selected

        :return: The asset_id of this AssetSelectionInputV1.
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """
        Sets the asset_id of this AssetSelectionInputV1.
        The asset selected

        :param asset_id: The asset_id of this AssetSelectionInputV1.
        :type: str
        """
        if asset_id is None:
            raise ValueError("Invalid value for `asset_id`, must not be `None`")

        self._asset_id = asset_id

    @property
    def asset_path_depth(self):
        """
        Gets the asset_path_depth of this AssetSelectionInputV1.
        Max depth for asset path name for this selection

        :return: The asset_path_depth of this AssetSelectionInputV1.
        :rtype: int
        """
        return self._asset_path_depth

    @asset_path_depth.setter
    def asset_path_depth(self, asset_path_depth):
        """
        Sets the asset_path_depth of this AssetSelectionInputV1.
        Max depth for asset path name for this selection

        :param asset_path_depth: The asset_path_depth of this AssetSelectionInputV1.
        :type: int
        """

        self._asset_path_depth = asset_path_depth

    @property
    def description(self):
        """
        Gets the description of this AssetSelectionInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :return: The description of this AssetSelectionInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AssetSelectionInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :param description: The description of this AssetSelectionInputV1.
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """
        Gets the name of this AssetSelectionInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :return: The name of this AssetSelectionInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AssetSelectionInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :param name: The name of this AssetSelectionInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def report_id(self):
        """
        Gets the report_id of this AssetSelectionInputV1.
        The asset selection's report

        :return: The report_id of this AssetSelectionInputV1.
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """
        Sets the report_id of this AssetSelectionInputV1.
        The asset selection's report

        :param report_id: The report_id of this AssetSelectionInputV1.
        :type: str
        """

        self._report_id = report_id

    @property
    def selection_id(self):
        """
        Gets the selection_id of this AssetSelectionInputV1.
        Seeq Id for the asset selection

        :return: The selection_id of this AssetSelectionInputV1.
        :rtype: str
        """
        return self._selection_id

    @selection_id.setter
    def selection_id(self, selection_id):
        """
        Sets the selection_id of this AssetSelectionInputV1.
        Seeq Id for the asset selection

        :param selection_id: The selection_id of this AssetSelectionInputV1.
        :type: str
        """

        self._selection_id = selection_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AssetSelectionInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FormulaDocSummaryOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'documentation_href': 'str',
        'excel_synonyms': 'list[str]',
        'fluent': 'bool',
        'keywords': 'list[str]',
        'name': 'str',
        'short_description': 'str'
    }

    attribute_map = {
        'description': 'description',
        'documentation_href': 'documentationHref',
        'excel_synonyms': 'excelSynonyms',
        'fluent': 'fluent',
        'keywords': 'keywords',
        'name': 'name',
        'short_description': 'shortDescription'
    }

    def __init__(self, description=None, documentation_href=None, excel_synonyms=None, fluent=False, keywords=None, name=None, short_description=None):
        """
        FormulaDocSummaryOutputV1 - a model defined in Swagger
        """

        self._description = None
        self._documentation_href = None
        self._excel_synonyms = None
        self._fluent = None
        self._keywords = None
        self._name = None
        self._short_description = None

        if description is not None:
          self.description = description
        if documentation_href is not None:
          self.documentation_href = documentation_href
        if excel_synonyms is not None:
          self.excel_synonyms = excel_synonyms
        if fluent is not None:
          self.fluent = fluent
        if keywords is not None:
          self.keywords = keywords
        if name is not None:
          self.name = name
        if short_description is not None:
          self.short_description = short_description

    @property
    def description(self):
        """
        Gets the description of this FormulaDocSummaryOutputV1.
        A detailed description of the page

        :return: The description of this FormulaDocSummaryOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this FormulaDocSummaryOutputV1.
        A detailed description of the page

        :param description: The description of this FormulaDocSummaryOutputV1.
        :type: str
        """

        self._description = description

    @property
    def documentation_href(self):
        """
        Gets the documentation_href of this FormulaDocSummaryOutputV1.
        The href to the documentation

        :return: The documentation_href of this FormulaDocSummaryOutputV1.
        :rtype: str
        """
        return self._documentation_href

    @documentation_href.setter
    def documentation_href(self, documentation_href):
        """
        Sets the documentation_href of this FormulaDocSummaryOutputV1.
        The href to the documentation

        :param documentation_href: The documentation_href of this FormulaDocSummaryOutputV1.
        :type: str
        """

        self._documentation_href = documentation_href

    @property
    def excel_synonyms(self):
        """
        Gets the excel_synonyms of this FormulaDocSummaryOutputV1.
        Search synonyms for this document, generally corresponding to an excel function

        :return: The excel_synonyms of this FormulaDocSummaryOutputV1.
        :rtype: list[str]
        """
        return self._excel_synonyms

    @excel_synonyms.setter
    def excel_synonyms(self, excel_synonyms):
        """
        Sets the excel_synonyms of this FormulaDocSummaryOutputV1.
        Search synonyms for this document, generally corresponding to an excel function

        :param excel_synonyms: The excel_synonyms of this FormulaDocSummaryOutputV1.
        :type: list[str]
        """

        self._excel_synonyms = excel_synonyms

    @property
    def fluent(self):
        """
        Gets the fluent of this FormulaDocSummaryOutputV1.

        :return: The fluent of this FormulaDocSummaryOutputV1.
        :rtype: bool
        """
        return self._fluent

    @fluent.setter
    def fluent(self, fluent):
        """
        Sets the fluent of this FormulaDocSummaryOutputV1.

        :param fluent: The fluent of this FormulaDocSummaryOutputV1.
        :type: bool
        """

        self._fluent = fluent

    @property
    def keywords(self):
        """
        Gets the keywords of this FormulaDocSummaryOutputV1.
        Keywords of the documentation page

        :return: The keywords of this FormulaDocSummaryOutputV1.
        :rtype: list[str]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """
        Sets the keywords of this FormulaDocSummaryOutputV1.
        Keywords of the documentation page

        :param keywords: The keywords of this FormulaDocSummaryOutputV1.
        :type: list[str]
        """

        self._keywords = keywords

    @property
    def name(self):
        """
        Gets the name of this FormulaDocSummaryOutputV1.
        The identifier of the documentation

        :return: The name of this FormulaDocSummaryOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FormulaDocSummaryOutputV1.
        The identifier of the documentation

        :param name: The name of this FormulaDocSummaryOutputV1.
        :type: str
        """

        self._name = name

    @property
    def short_description(self):
        """
        Gets the short_description of this FormulaDocSummaryOutputV1.
        A short description of the page

        :return: The short_description of this FormulaDocSummaryOutputV1.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this FormulaDocSummaryOutputV1.
        A short description of the page

        :param short_description: The short_description of this FormulaDocSummaryOutputV1.
        :type: str
        """

        self._short_description = short_description

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FormulaDocSummaryOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SignalWithIdInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_properties': 'list[ScalarPropertyV1]',
        'data_id': 'str',
        'datasource_class': 'str',
        'datasource_id': 'str',
        'description': 'str',
        'formula': 'str',
        'formula_parameters': 'list[str]',
        'historical_data_version': 'str',
        'interpolation_method': 'str',
        'key_unit_of_measure': 'str',
        'maximum_interpolation': 'str',
        'name': 'str',
        'number_format': 'str',
        'previous_data_id': 'str',
        'scoped_to': 'str',
        'security_string': 'str',
        'source_security_string': 'str',
        'sync_token': 'str',
        'value_unit_of_measure': 'str'
    }

    attribute_map = {
        'additional_properties': 'additionalProperties',
        'data_id': 'dataId',
        'datasource_class': 'datasourceClass',
        'datasource_id': 'datasourceId',
        'description': 'description',
        'formula': 'formula',
        'formula_parameters': 'formulaParameters',
        'historical_data_version': 'historicalDataVersion',
        'interpolation_method': 'interpolationMethod',
        'key_unit_of_measure': 'keyUnitOfMeasure',
        'maximum_interpolation': 'maximumInterpolation',
        'name': 'name',
        'number_format': 'numberFormat',
        'previous_data_id': 'previousDataId',
        'scoped_to': 'scopedTo',
        'security_string': 'securityString',
        'source_security_string': 'sourceSecurityString',
        'sync_token': 'syncToken',
        'value_unit_of_measure': 'valueUnitOfMeasure'
    }

    def __init__(self, additional_properties=None, data_id=None, datasource_class=None, datasource_id=None, description=None, formula=None, formula_parameters=None, historical_data_version=None, interpolation_method=None, key_unit_of_measure=None, maximum_interpolation=None, name=None, number_format=None, previous_data_id=None, scoped_to=None, security_string=None, source_security_string=None, sync_token=None, value_unit_of_measure=None):
        """
        SignalWithIdInputV1 - a model defined in Swagger
        """

        self._additional_properties = None
        self._data_id = None
        self._datasource_class = None
        self._datasource_id = None
        self._description = None
        self._formula = None
        self._formula_parameters = None
        self._historical_data_version = None
        self._interpolation_method = None
        self._key_unit_of_measure = None
        self._maximum_interpolation = None
        self._name = None
        self._number_format = None
        self._previous_data_id = None
        self._scoped_to = None
        self._security_string = None
        self._source_security_string = None
        self._sync_token = None
        self._value_unit_of_measure = None

        if additional_properties is not None:
          self.additional_properties = additional_properties
        if data_id is not None:
          self.data_id = data_id
        if datasource_class is not None:
          self.datasource_class = datasource_class
        if datasource_id is not None:
          self.datasource_id = datasource_id
        if description is not None:
          self.description = description
        if formula is not None:
          self.formula = formula
        if formula_parameters is not None:
          self.formula_parameters = formula_parameters
        if historical_data_version is not None:
          self.historical_data_version = historical_data_version
        if interpolation_method is not None:
          self.interpolation_method = interpolation_method
        if key_unit_of_measure is not None:
          self.key_unit_of_measure = key_unit_of_measure
        if maximum_interpolation is not None:
          self.maximum_interpolation = maximum_interpolation
        if name is not None:
          self.name = name
        if number_format is not None:
          self.number_format = number_format
        if previous_data_id is not None:
          self.previous_data_id = previous_data_id
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if security_string is not None:
          self.security_string = security_string
        if source_security_string is not None:
          self.source_security_string = source_security_string
        if sync_token is not None:
          self.sync_token = sync_token
        if value_unit_of_measure is not None:
          self.value_unit_of_measure = value_unit_of_measure

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this SignalWithIdInputV1.
        Additional properties to set on this signal. A property consists of a name, a value, and a unit of measure.

        :return: The additional_properties of this SignalWithIdInputV1.
        :rtype: list[ScalarPropertyV1]
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this SignalWithIdInputV1.
        Additional properties to set on this signal. A property consists of a name, a value, and a unit of measure.

        :param additional_properties: The additional_properties of this SignalWithIdInputV1.
        :type: list[ScalarPropertyV1]
        """

        self._additional_properties = additional_properties

    @property
    def data_id(self):
        """
        Gets the data_id of this SignalWithIdInputV1.
        The data ID of this item. Note: This is not the Seeq ID, but the unique identifier that the remote datasource uses.

        :return: The data_id of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._data_id

    @data_id.setter
    def data_id(self, data_id):
        """
        Sets the data_id of this SignalWithIdInputV1.
        The data ID of this item. Note: This is not the Seeq ID, but the unique identifier that the remote datasource uses.

        :param data_id: The data_id of this SignalWithIdInputV1.
        :type: str
        """

        self._data_id = data_id

    @property
    def datasource_class(self):
        """
        Gets the datasource_class of this SignalWithIdInputV1.
        Along with the Datasource ID, the Datasource Class uniquely identifies a datasource. For example, a datasource may be a particular instance of an OSIsoft PI historian.

        :return: The datasource_class of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._datasource_class

    @datasource_class.setter
    def datasource_class(self, datasource_class):
        """
        Sets the datasource_class of this SignalWithIdInputV1.
        Along with the Datasource ID, the Datasource Class uniquely identifies a datasource. For example, a datasource may be a particular instance of an OSIsoft PI historian.

        :param datasource_class: The datasource_class of this SignalWithIdInputV1.
        :type: str
        """

        self._datasource_class = datasource_class

    @property
    def datasource_id(self):
        """
        Gets the datasource_id of this SignalWithIdInputV1.
        Along with the Datasource Class, the Datasource ID uniquely identifies a datasource. For example, a datasource may be a particular instance of an OSIsoft PI historian.

        :return: The datasource_id of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """
        Sets the datasource_id of this SignalWithIdInputV1.
        Along with the Datasource Class, the Datasource ID uniquely identifies a datasource. For example, a datasource may be a particular instance of an OSIsoft PI historian.

        :param datasource_id: The datasource_id of this SignalWithIdInputV1.
        :type: str
        """

        self._datasource_id = datasource_id

    @property
    def description(self):
        """
        Gets the description of this SignalWithIdInputV1.
        A description of the signal.

        :return: The description of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SignalWithIdInputV1.
        A description of the signal.

        :param description: The description of this SignalWithIdInputV1.
        :type: str
        """

        self._description = description

    @property
    def formula(self):
        """
        Gets the formula of this SignalWithIdInputV1.
        For a calculated signal, the Seeq Formula defining the signal.

        :return: The formula of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._formula

    @formula.setter
    def formula(self, formula):
        """
        Sets the formula of this SignalWithIdInputV1.
        For a calculated signal, the Seeq Formula defining the signal.

        :param formula: The formula of this SignalWithIdInputV1.
        :type: str
        """

        self._formula = formula

    @property
    def formula_parameters(self):
        """
        Gets the formula_parameters of this SignalWithIdInputV1.

        :return: The formula_parameters of this SignalWithIdInputV1.
        :rtype: list[str]
        """
        return self._formula_parameters

    @formula_parameters.setter
    def formula_parameters(self, formula_parameters):
        """
        Sets the formula_parameters of this SignalWithIdInputV1.

        :param formula_parameters: The formula_parameters of this SignalWithIdInputV1.
        :type: list[str]
        """

        self._formula_parameters = formula_parameters

    @property
    def historical_data_version(self):
        """
        Gets the historical_data_version of this SignalWithIdInputV1.
        This property tells Seeq that certain, and thus potentially cached, samples in the past have been changed. Changing the value of this property will will clear the cache of this signal and all formulas that depend on it. It should not be changed when new uncached samples are coming in.

        :return: The historical_data_version of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._historical_data_version

    @historical_data_version.setter
    def historical_data_version(self, historical_data_version):
        """
        Sets the historical_data_version of this SignalWithIdInputV1.
        This property tells Seeq that certain, and thus potentially cached, samples in the past have been changed. Changing the value of this property will will clear the cache of this signal and all formulas that depend on it. It should not be changed when new uncached samples are coming in.

        :param historical_data_version: The historical_data_version of this SignalWithIdInputV1.
        :type: str
        """

        self._historical_data_version = historical_data_version

    @property
    def interpolation_method(self):
        """
        Gets the interpolation_method of this SignalWithIdInputV1.
        The interpolation method used to represent the values between samples in the signal. The possibilities are: Linear, PILinear, and Step. If not specified, Linear will be used.

        :return: The interpolation_method of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._interpolation_method

    @interpolation_method.setter
    def interpolation_method(self, interpolation_method):
        """
        Sets the interpolation_method of this SignalWithIdInputV1.
        The interpolation method used to represent the values between samples in the signal. The possibilities are: Linear, PILinear, and Step. If not specified, Linear will be used.

        :param interpolation_method: The interpolation_method of this SignalWithIdInputV1.
        :type: str
        """

        self._interpolation_method = interpolation_method

    @property
    def key_unit_of_measure(self):
        """
        Gets the key_unit_of_measure of this SignalWithIdInputV1.
        The unit of measure for the signal's keys. The default is a time-keyed signal, with key units of 'ns'.

        :return: The key_unit_of_measure of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._key_unit_of_measure

    @key_unit_of_measure.setter
    def key_unit_of_measure(self, key_unit_of_measure):
        """
        Sets the key_unit_of_measure of this SignalWithIdInputV1.
        The unit of measure for the signal's keys. The default is a time-keyed signal, with key units of 'ns'.

        :param key_unit_of_measure: The key_unit_of_measure of this SignalWithIdInputV1.
        :type: str
        """

        self._key_unit_of_measure = key_unit_of_measure

    @property
    def maximum_interpolation(self):
        """
        Gets the maximum_interpolation of this SignalWithIdInputV1.
        The maximum spacing between adjacent sample keys that can be interpolated across. If two samples are spaced by more than maximum interpolation, there will be a hole in the signal between them.

        :return: The maximum_interpolation of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._maximum_interpolation

    @maximum_interpolation.setter
    def maximum_interpolation(self, maximum_interpolation):
        """
        Sets the maximum_interpolation of this SignalWithIdInputV1.
        The maximum spacing between adjacent sample keys that can be interpolated across. If two samples are spaced by more than maximum interpolation, there will be a hole in the signal between them.

        :param maximum_interpolation: The maximum_interpolation of this SignalWithIdInputV1.
        :type: str
        """

        self._maximum_interpolation = maximum_interpolation

    @property
    def name(self):
        """
        Gets the name of this SignalWithIdInputV1.
        The name of the signal.

        :return: The name of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SignalWithIdInputV1.
        The name of the signal.

        :param name: The name of this SignalWithIdInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def number_format(self):
        """
        Gets the number_format of this SignalWithIdInputV1.
        The format string used for numbers associated with this signal. The format for the string follows ECMA-376 spreadsheet format standards.

        :return: The number_format of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._number_format

    @number_format.setter
    def number_format(self, number_format):
        """
        Sets the number_format of this SignalWithIdInputV1.
        The format string used for numbers associated with this signal. The format for the string follows ECMA-376 spreadsheet format standards.

        :param number_format: The number_format of this SignalWithIdInputV1.
        :type: str
        """

        self._number_format = number_format

    @property
    def previous_data_id(self):
        """
        Gets the previous_data_id of this SignalWithIdInputV1.
        Previous Data ID for the item within its datasource; ignored if null. It should only be used when the Data ID of an item in a datasource is being changed but should still map to the same item in Seeq - this could be because a datasource item has been moved or to improve logic related to the use of Data IDs

        :return: The previous_data_id of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._previous_data_id

    @previous_data_id.setter
    def previous_data_id(self, previous_data_id):
        """
        Sets the previous_data_id of this SignalWithIdInputV1.
        Previous Data ID for the item within its datasource; ignored if null. It should only be used when the Data ID of an item in a datasource is being changed but should still map to the same item in Seeq - this could be because a datasource item has been moved or to improve logic related to the use of Data IDs

        :param previous_data_id: The previous_data_id of this SignalWithIdInputV1.
        :type: str
        """

        self._previous_data_id = previous_data_id

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this SignalWithIdInputV1.
        The ID of the workbook to which this item will be scoped. If not provided, the signal will have global scope.

        :return: The scoped_to of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this SignalWithIdInputV1.
        The ID of the workbook to which this item will be scoped. If not provided, the signal will have global scope.

        :param scoped_to: The scoped_to of this SignalWithIdInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def security_string(self):
        """
        Gets the security_string of this SignalWithIdInputV1.
        Security string containing all identities and their permissions for the item. If set, permissions can only be managed by the connector and not in Seeq.

        :return: The security_string of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._security_string

    @security_string.setter
    def security_string(self, security_string):
        """
        Sets the security_string of this SignalWithIdInputV1.
        Security string containing all identities and their permissions for the item. If set, permissions can only be managed by the connector and not in Seeq.

        :param security_string: The security_string of this SignalWithIdInputV1.
        :type: str
        """

        self._security_string = security_string

    @property
    def source_security_string(self):
        """
        Gets the source_security_string of this SignalWithIdInputV1.
        The security string as it was originally found on the source (for debugging ACLs only)

        :return: The source_security_string of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._source_security_string

    @source_security_string.setter
    def source_security_string(self, source_security_string):
        """
        Sets the source_security_string of this SignalWithIdInputV1.
        The security string as it was originally found on the source (for debugging ACLs only)

        :param source_security_string: The source_security_string of this SignalWithIdInputV1.
        :type: str
        """

        self._source_security_string = source_security_string

    @property
    def sync_token(self):
        """
        Gets the sync_token of this SignalWithIdInputV1.
        An arbitrary token (often a date or random ID) that is used during metadata syncs. At the end of a full sync, items with mismatching sync tokens are identified as stale and may be  archived using the Datasources clean-up API.

        :return: The sync_token of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._sync_token

    @sync_token.setter
    def sync_token(self, sync_token):
        """
        Sets the sync_token of this SignalWithIdInputV1.
        An arbitrary token (often a date or random ID) that is used during metadata syncs. At the end of a full sync, items with mismatching sync tokens are identified as stale and may be  archived using the Datasources clean-up API.

        :param sync_token: The sync_token of this SignalWithIdInputV1.
        :type: str
        """

        self._sync_token = sync_token

    @property
    def value_unit_of_measure(self):
        """
        Gets the value_unit_of_measure of this SignalWithIdInputV1.
        The unit of measure for the signal's values. The default is unitless.

        :return: The value_unit_of_measure of this SignalWithIdInputV1.
        :rtype: str
        """
        return self._value_unit_of_measure

    @value_unit_of_measure.setter
    def value_unit_of_measure(self, value_unit_of_measure):
        """
        Sets the value_unit_of_measure of this SignalWithIdInputV1.
        The unit of measure for the signal's values. The default is unitless.

        :param value_unit_of_measure: The value_unit_of_measure of this SignalWithIdInputV1.
        :type: str
        """

        self._value_unit_of_measure = value_unit_of_measure

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SignalWithIdInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

__version__ = "62.0.10"

# import models into sdk package
from .access_key_input_v1 import AccessKeyInputV1
from .access_key_output_list_v1 import AccessKeyOutputListV1
from .access_key_output_v1 import AccessKeyOutputV1
from .ace_input_v1 import AceInputV1
from .ace_output_v1 import AceOutputV1
from .acl_input_v1 import AclInputV1
from .acl_output_v1 import AclOutputV1
from .activity_graph_output_v1 import ActivityGraphOutputV1
from .activity_output_v1 import ActivityOutputV1
from .add_on_input_v1 import AddOnInputV1
from .add_on_output_list_v1 import AddOnOutputListV1
from .add_on_output_v1 import AddOnOutputV1
from .add_on_preview_output_list_v1 import AddOnPreviewOutputListV1
from .add_on_preview_v1 import AddOnPreviewV1
from .add_on_tool_input_v1 import AddOnToolInputV1
from .add_on_tool_output_v1 import AddOnToolOutputV1
from .administrator_contact_information_v1 import AdministratorContactInformationV1
from .agent_input_v1 import AgentInputV1
from .agent_key_output_v1 import AgentKeyOutputV1
from .agent_output_v1 import AgentOutputV1
from .agent_status_output_v1 import AgentStatusOutputV1
from .agent_status_v1 import AgentStatusV1
from .annotation_image_link_output_v1 import AnnotationImageLinkOutputV1
from .annotation_input_v1 import AnnotationInputV1
from .annotation_interest_input_v1 import AnnotationInterestInputV1
from .annotation_interest_output_v1 import AnnotationInterestOutputV1
from .annotation_list_output_v1 import AnnotationListOutputV1
from .annotation_output_v1 import AnnotationOutputV1
from .archive_output_v1 import ArchiveOutputV1
from .asset_batch_input_v1 import AssetBatchInputV1
from .asset_error import AssetError
from .asset_group_asset_input_v1 import AssetGroupAssetInputV1
from .asset_group_input_v1 import AssetGroupInputV1
from .asset_group_output_v1 import AssetGroupOutputV1
from .asset_group_root_input_v1 import AssetGroupRootInputV1
from .asset_group_tree_output_v1 import AssetGroupTreeOutputV1
from .asset_input_v1 import AssetInputV1
from .asset_output_v1 import AssetOutputV1
from .asset_selection_input_v1 import AssetSelectionInputV1
from .asset_selection_output_v1 import AssetSelectionOutputV1
from .asset_tree_batch_input_v1 import AssetTreeBatchInputV1
from .asset_tree_output_v1 import AssetTreeOutputV1
from .asset_tree_single_input_v1 import AssetTreeSingleInputV1
from .attachment_input_v1 import AttachmentInputV1
from .audit_output_list_v1 import AuditOutputListV1
from .audit_output_v1 import AuditOutputV1
from .auth_input_v1 import AuthInputV1
from .auth_providers_output_v1 import AuthProvidersOutputV1
from .cache_info_v1 import CacheInfoV1
from .calculated_item_output_v1 import CalculatedItemOutputV1
from .capsule_input_v1 import CapsuleInputV1
from .capsule_property_input_v1 import CapsulePropertyInputV1
from .capsule_property_output_v1 import CapsulePropertyOutputV1
from .capsule_v1 import CapsuleV1
from .capsules_input_v1 import CapsulesInputV1
from .capsules_output_v1 import CapsulesOutputV1
from .capsules_overwrite_input_v1 import CapsulesOverwriteInputV1
from .channel_output_v1 import ChannelOutputV1
from .column_definition_input_v1 import ColumnDefinitionInputV1
from .column_definition_output_v1 import ColumnDefinitionOutputV1
from .column_rule import ColumnRule
from .column_rule_ancestor_input_v1 import ColumnRuleAncestorInputV1
from .column_rule_concat_input_v1 import ColumnRuleConcatInputV1
from .column_rule_event_property_input_v1 import ColumnRuleEventPropertyInputV1
from .column_rule_input_v1 import ColumnRuleInputV1
from .column_rule_item_property_input_v1 import ColumnRuleItemPropertyInputV1
from .column_rule_path_input_v1 import ColumnRulePathInputV1
from .condition_batch_input_v1 import ConditionBatchInputV1
from .condition_input_v1 import ConditionInputV1
from .condition_monitor_input_v1 import ConditionMonitorInputV1
from .condition_monitor_notification_configuration_input_v1 import ConditionMonitorNotificationConfigurationInputV1
from .condition_monitor_output_v1 import ConditionMonitorOutputV1
from .condition_notification_output_list_v1 import ConditionNotificationOutputListV1
from .condition_notification_output_v1 import ConditionNotificationOutputV1
from .condition_output_v1 import ConditionOutputV1
from .condition_update_input_v1 import ConditionUpdateInputV1
from .configuration_input_v1 import ConfigurationInputV1
from .configuration_option_input_v1 import ConfigurationOptionInputV1
from .configuration_option_output_simple_v1 import ConfigurationOptionOutputSimpleV1
from .configuration_option_output_v1 import ConfigurationOptionOutputV1
from .configuration_output_v1 import ConfigurationOutputV1
from .configured_directives_output_v1 import ConfiguredDirectivesOutputV1
from .connection_input_v1 import ConnectionInputV1
from .connection_output_v1 import ConnectionOutputV1
from .connection_status_output_v1 import ConnectionStatusOutputV1
from .connection_status_v1 import ConnectionStatusV1
from .connections_output_v1 import ConnectionsOutputV1
from .connector_input_v1 import ConnectorInputV1
from .connector_output_v1 import ConnectorOutputV1
from .connectors_output_v1 import ConnectorsOutputV1
from .content_input_v1 import ContentInputV1
from .content_output_v1 import ContentOutputV1
from .content_with_metadata_list_output_v1 import ContentWithMetadataListOutputV1
from .content_with_metadata_output_v1 import ContentWithMetadataOutputV1
from .context_comment_input_v1 import ContextCommentInputV1
from .context_comment_output_v1 import ContextCommentOutputV1
from .context_label_input_v1 import ContextLabelInputV1
from .context_label_output_v1 import ContextLabelOutputV1
from .context_opaque_input_v1 import ContextOpaqueInputV1
from .context_opaque_output_v1 import ContextOpaqueOutputV1
from .context_output_list_v1 import ContextOutputListV1
from .csv_datafile_output_v1 import CsvDatafileOutputV1
from .datafile_input_v1 import DatafileInputV1
from .datafile_output_v1 import DatafileOutputV1
from .datafiles_csv_body import DatafilesCsvBody
from .datasource_clean_up_input_v1 import DatasourceCleanUpInputV1
from .datasource_clean_up_output_v1 import DatasourceCleanUpOutputV1
from .datasource_input_v1 import DatasourceInputV1
from .datasource_output_list_v1 import DatasourceOutputListV1
from .datasource_output_v1 import DatasourceOutputV1
from .datasource_preview_v1 import DatasourcePreviewV1
from .datasource_statistics_v1 import DatasourceStatisticsV1
from .datasource_status_output_v1 import DatasourceStatusOutputV1
from .datasource_status_v1 import DatasourceStatusV1
from .datasource_summary_status_output_v1 import DatasourceSummaryStatusOutputV1
from .datasources_status_output_v1 import DatasourcesStatusOutputV1
from .date_range_input_v1 import DateRangeInputV1
from .date_range_output_v1 import DateRangeOutputV1
from .detailed_meter_output_v1 import DetailedMeterOutputV1
from .detailed_timer_output_v1 import DetailedTimerOutputV1
from .directive_input_v1 import DirectiveInputV1
from .display_input_v1 import DisplayInputV1
from .display_output_list_v1 import DisplayOutputListV1
from .display_output_v1 import DisplayOutputV1
from .display_template_input_v1 import DisplayTemplateInputV1
from .display_template_output_list_v1 import DisplayTemplateOutputListV1
from .display_template_output_v1 import DisplayTemplateOutputV1
from .document_backup_output_v1 import DocumentBackupOutputV1
from .email_notification_recipient_output_v1 import EmailNotificationRecipientOutputV1
from .emailer_configuration_output_v1 import EmailerConfigurationOutputV1
from .export_item_v1 import ExportItemV1
from .export_items_output_v1 import ExportItemsOutputV1
from .export_items_v1 import ExportItemsV1
from .export_preview_list_v1 import ExportPreviewListV1
from .export_preview_v1 import ExportPreviewV1
from .folded_stack_node_v1 import FoldedStackNodeV1
from .folder_input_v1 import FolderInputV1
from .folder_navigation_output_v1 import FolderNavigationOutputV1
from .folder_output_v1 import FolderOutputV1
from .formula_compile_output_v1 import FormulaCompileOutputV1
from .formula_compiler_error_output_v1 import FormulaCompilerErrorOutputV1
from .formula_dependency_input_v1 import FormulaDependencyInputV1
from .formula_doc_example_input_v1 import FormulaDocExampleInputV1
from .formula_doc_example_list_input_v1 import FormulaDocExampleListInputV1
from .formula_doc_input_v1 import FormulaDocInputV1
from .formula_doc_keyword_list_input_v1 import FormulaDocKeywordListInputV1
from .formula_doc_output_v1 import FormulaDocOutputV1
from .formula_doc_summaries_output_v1 import FormulaDocSummariesOutputV1
from .formula_doc_summary_output_v1 import FormulaDocSummaryOutputV1
from .formula_error_output_v1 import FormulaErrorOutputV1
from .formula_example_output_v1 import FormulaExampleOutputV1
from .formula_item_input_v1 import FormulaItemInputV1
from .formula_item_output_v1 import FormulaItemOutputV1
from .formula_log_entry import FormulaLogEntry
from .formula_log_entry_details import FormulaLogEntryDetails
from .formula_log_v1 import FormulaLogV1
from .formula_package_import_input_v1 import FormulaPackageImportInputV1
from .formula_package_import_output_v1 import FormulaPackageImportOutputV1
from .formula_package_input_v1 import FormulaPackageInputV1
from .formula_package_output_v1 import FormulaPackageOutputV1
from .formula_parameter_input_v1 import FormulaParameterInputV1
from .formula_parameter_output_v1 import FormulaParameterOutputV1
from .formula_run_input_v1 import FormulaRunInputV1
from .formula_run_output_v1 import FormulaRunOutputV1
from .formula_token import FormulaToken
from .formula_update_input_v1 import FormulaUpdateInputV1
from .formula_upgrade_change_v1 import FormulaUpgradeChangeV1
from .formula_upgrade_output_v1 import FormulaUpgradeOutputV1
from .function_input_v1 import FunctionInputV1
from .function_parameter_output_v1 import FunctionParameterOutputV1
from .function_variant_output_v1 import FunctionVariantOutputV1
from .gauge_datum_v1 import GaugeDatumV1
from .generic_table_output_v1 import GenericTableOutputV1
from .get_add_on_tools_output_v1 import GetAddOnToolsOutputV1
from .get_channels_output_v1 import GetChannelsOutputV1
from .get_condition_monitor_items_output_v1 import GetConditionMonitorItemsOutputV1
from .get_content_items_output_v1 import GetContentItemsOutputV1
from .get_date_ranges_output_v1 import GetDateRangesOutputV1
from .get_jobs_output_v1 import GetJobsOutputV1
from .get_metrics_output_v1 import GetMetricsOutputV1
from .get_projects_output_v1 import GetProjectsOutputV1
from .get_request_output_v1 import GetRequestOutputV1
from .get_requests_output_v1 import GetRequestsOutputV1
from .get_sample_output_v1 import GetSampleOutputV1
from .get_samples_output_v1 import GetSamplesOutputV1
from .get_signals_output_v1 import GetSignalsOutputV1
from .graph_ql_input_v1 import GraphQLInputV1
from .graph_ql_output_v1 import GraphQLOutputV1
from .id_images_body import IdImagesBody
from .identity_mapping_list_v1 import IdentityMappingListV1
from .identity_mapping_v1 import IdentityMappingV1
from .identity_preview_list_v1 import IdentityPreviewListV1
from .identity_preview_v1 import IdentityPreviewV1
from .indexing_parameters_input_v1 import IndexingParametersInputV1
from .installer_output_v1 import InstallerOutputV1
from .interval_v1 import IntervalV1
from .invalid_swap_out_v1 import InvalidSwapOutV1
from .item_batch_output_v1 import ItemBatchOutputV1
from .item_dependency_output_v1 import ItemDependencyOutputV1
from .item_finder_configuration_v1 import ItemFinderConfigurationV1
from .item_finder_input_v1 import ItemFinderInputV1
from .item_finder_output_list_v1 import ItemFinderOutputListV1
from .item_finder_output_v1 import ItemFinderOutputV1
from .item_id_list_input_v1 import ItemIdListInputV1
from .item_output_v1 import ItemOutputV1
from .item_parameter_of_output_v1 import ItemParameterOfOutputV1
from .item_preview_list_v1 import ItemPreviewListV1
from .item_preview_v1 import ItemPreviewV1
from .item_preview_with_assets_v1 import ItemPreviewWithAssetsV1
from .item_search_preview_list_v1 import ItemSearchPreviewListV1
from .item_search_preview_paginated_list_v1 import ItemSearchPreviewPaginatedListV1
from .item_search_preview_v1 import ItemSearchPreviewV1
from .item_swap_result_output_v1 import ItemSwapResultOutputV1
from .item_update_output_v1 import ItemUpdateOutputV1
from .item_user_attributes_input_v1 import ItemUserAttributesInputV1
from .item_user_attributes_output_v1 import ItemUserAttributesOutputV1
from .item_with_swap_pairs_v1 import ItemWithSwapPairsV1
from .jira_attachment import JiraAttachment
from .jira_attachment_media_type import JiraAttachmentMediaType
from .job_accepted_output_v1 import JobAcceptedOutputV1
from .job_output_v1 import JobOutputV1
from .json_backup_output_v1 import JsonBackupOutputV1
from .label_category_input_v1 import LabelCategoryInputV1
from .label_category_output_list_v1 import LabelCategoryOutputListV1
from .label_category_output_v1 import LabelCategoryOutputV1
from .label_input_v1 import LabelInputV1
from .label_output_list_v1 import LabelOutputListV1
from .label_output_v1 import LabelOutputV1
from .license_importer_output_v1 import LicenseImporterOutputV1
from .license_status_output_v1 import LicenseStatusOutputV1
from .licensed_feature_status_output_v1 import LicensedFeatureStatusOutputV1
from .log_message import LogMessage
from .meter_datum_v1 import MeterDatumV1
from .migrate_editor_input_v1 import MigrateEditorInputV1
from .monitor_definition_output_v1 import MonitorDefinitionOutputV1
from .monitor_definitions_output_v1 import MonitorDefinitionsOutputV1
from .monitor_input_v1 import MonitorInputV1
from .monitor_output_v1 import MonitorOutputV1
from .monitor_values import MonitorValues
from .monitors_output_v1 import MonitorsOutputV1
from .notifiable_report_output_list_v1 import NotifiableReportOutputListV1
from .notifiable_report_output_v1 import NotifiableReportOutputV1
from .notification_configuration_output_v1 import NotificationConfigurationOutputV1
from .optional_report_input_v1 import OptionalReportInputV1
from .parameter_doc_output_v1 import ParameterDocOutputV1
from .permissions_v1 import PermissionsV1
from .plugin_output_list_v1 import PluginOutputListV1
from .plugin_output_v1 import PluginOutputV1
from .plugins_body import PluginsBody
from .priority_v1 import PriorityV1
from .progress_information_output_v1 import ProgressInformationOutputV1
from .project_input_v1 import ProjectInputV1
from .project_output_v1 import ProjectOutputV1
from .property_href_output_v1 import PropertyHrefOutputV1
from .property_input_v1 import PropertyInputV1
from .property_output_v1 import PropertyOutputV1
from .put_asset_input_v1 import PutAssetInputV1
from .put_scalar_input_v1 import PutScalarInputV1
from .put_scalars_input_v1 import PutScalarsInputV1
from .put_signals_input_v1 import PutSignalsInputV1
from .put_user_groups_input_v1 import PutUserGroupsInputV1
from .referenced_items_output_v1 import ReferencedItemsOutputV1
from .regression_output_v1 import RegressionOutputV1
from .remote_agent_directives_output_v1 import RemoteAgentDirectivesOutputV1
from .remote_agent_status_input_v1 import RemoteAgentStatusInputV1
from .remote_agent_status_output_v1 import RemoteAgentStatusOutputV1
from .report_input_item_v1 import ReportInputItemV1
from .report_input_v1 import ReportInputV1
from .report_notification_configuration_input_v1 import ReportNotificationConfigurationInputV1
from .report_template_input_v1 import ReportTemplateInputV1
from .report_template_output_v1 import ReportTemplateOutputV1
from .request_output_v1 import RequestOutputV1
from .sample_input_v1 import SampleInputV1
from .sample_output_v1 import SampleOutputV1
from .samples_input_v1 import SamplesInputV1
from .samples_output_v1 import SamplesOutputV1
from .samples_overwrite_input_v1 import SamplesOverwriteInputV1
from .scalar_evaluate_output_v1 import ScalarEvaluateOutputV1
from .scalar_input_v1 import ScalarInputV1
from .scalar_property_v1 import ScalarPropertyV1
from .scalar_value_output_v1 import ScalarValueOutputV1
from .scale_across_tree_output_v1 import ScaleAcrossTreeOutputV1
from .schedulable_admin_list_output_v1 import SchedulableAdminListOutputV1
from .schedulable_admin_output_v1 import SchedulableAdminOutputV1
from .schedulable_summary_day_output_v1 import SchedulableSummaryDayOutputV1
from .schedulable_summary_week_output_v1 import SchedulableSummaryWeekOutputV1
from .schedule_input_v1 import ScheduleInputV1
from .schedule_output_v1 import ScheduleOutputV1
from .scheduled_notebook_input_v1 import ScheduledNotebookInputV1
from .scheduled_notebook_list_output_v1 import ScheduledNotebookListOutputV1
from .scheduled_notebook_output_v1 import ScheduledNotebookOutputV1
from .screenshot_output_v1 import ScreenshotOutputV1
from .see_also_doc_output_v1 import SeeAlsoDocOutputV1
from .send_email_attachment_v1 import SendEmailAttachmentV1
from .send_email_contact_v1 import SendEmailContactV1
from .send_email_input_v1 import SendEmailInputV1
from .server_build_info_output_v1 import ServerBuildInfoOutputV1
from .server_load_output_v1 import ServerLoadOutputV1
from .server_spec_output_v1 import ServerSpecOutputV1
from .server_status_output_v1 import ServerStatusOutputV1
from .signal_input_v1 import SignalInputV1
from .signal_output_v1 import SignalOutputV1
from .signal_with_id_input_v1 import SignalWithIdInputV1
from .status_message import StatusMessage
from .status_message_base import StatusMessageBase
from .subscription_input_v1 import SubscriptionInputV1
from .subscription_output_v1 import SubscriptionOutputV1
from .subscription_update_input_v1 import SubscriptionUpdateInputV1
from .support_request_input_v1 import SupportRequestInputV1
from .support_request_output_v1 import SupportRequestOutputV1
from .supported_units_output_v1 import SupportedUnitsOutputV1
from .swap_input_v1 import SwapInputV1
from .swap_option_list_v1 import SwapOptionListV1
from .swap_option_v1 import SwapOptionV1
from .swap_output_v1 import SwapOutputV1
from .sync_progress import SyncProgress
from .sync_progress_output_v1 import SyncProgressOutputV1
from .system_license_body import SystemLicenseBody
from .table_column_output_v1 import TableColumnOutputV1
from .table_definition_input_v1 import TableDefinitionInputV1
from .table_definition_output_list_v1 import TableDefinitionOutputListV1
from .table_definition_output_v1 import TableDefinitionOutputV1
from .threshold_metric_input_v1 import ThresholdMetricInputV1
from .threshold_metric_output_v1 import ThresholdMetricOutputV1
from .threshold_output_v1 import ThresholdOutputV1
from .timer_datum_v1 import TimerDatumV1
from .tree_item_output_v1 import TreeItemOutputV1
from .treemap_item_output_v1 import TreemapItemOutputV1
from .treemap_output_v1 import TreemapOutputV1
from .units_of_measure_batch_input_v1 import UnitsOfMeasureBatchInputV1
from .units_of_measure_item_v1 import UnitsOfMeasureItemV1
from .units_of_measure_output_v1 import UnitsOfMeasureOutputV1
from .unsubscribe_output_v1 import UnsubscribeOutputV1
from .usage_output_list_v1 import UsageOutputListV1
from .usage_output_v1 import UsageOutputV1
from .usage_types_v1 import UsageTypesV1
from .user_group_input_v1 import UserGroupInputV1
from .user_group_output_v1 import UserGroupOutputV1
from .user_group_with_id_input_v1 import UserGroupWithIdInputV1
from .user_input_v1 import UserInputV1
from .user_output_list_v1 import UserOutputListV1
from .user_output_v1 import UserOutputV1
from .user_password_input_v1 import UserPasswordInputV1
from .validate_cron_list_input_v1 import ValidateCronListInputV1
from .validate_cron_list_output_v1 import ValidateCronListOutputV1
from .validate_cron_output_v1 import ValidateCronOutputV1
from .workbench_item_output_list_v1 import WorkbenchItemOutputListV1
from .workbench_search_result_preview_v1 import WorkbenchSearchResultPreviewV1
from .workbook_input_v1 import WorkbookInputV1
from .workbook_output_list_v1 import WorkbookOutputListV1
from .workbook_output_v1 import WorkbookOutputV1
from .worksheet_input_v1 import WorksheetInputV1
from .worksheet_output_list_v1 import WorksheetOutputListV1
from .worksheet_output_v1 import WorksheetOutputV1
from .workstep_input_v1 import WorkstepInputV1
from .workstep_output_v1 import WorkstepOutputV1



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class AnnotationsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def archive_annotation(self, **kwargs):
        """
        Archive an annotation
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_annotation(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the annotation to archive (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.archive_annotation_with_http_info(**kwargs)
        else:
            (data) = self.archive_annotation_with_http_info(**kwargs)
            return data

    def archive_annotation_with_http_info(self, **kwargs):
        """
        Archive an annotation
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_annotation_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the annotation to archive (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_annotation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `archive_annotation`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def cors_image_proxy(self, **kwargs):
        """
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.cors_image_proxy(image_url=image_url_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str accept:
        :param str image_url: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.cors_image_proxy_with_http_info(**kwargs)
        else:
            (data) = self.cors_image_proxy_with_http_info(**kwargs)
            return data

    def cors_image_proxy_with_http_info(self, **kwargs):
        """
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.cors_image_proxy_with_http_info(image_url=image_url_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str accept:
        :param str image_url: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        all_params = ['accept', 'image_url']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cors_image_proxy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'image_url' is set
        if ('image_url' not in params) or (params['image_url'] is None):
            raise ValueError("Missing the required parameter `image_url` when calling `cors_image_proxy`")


        collection_formats = {}

        path_params = {}
        if 'image_url' in params:
            path_params['imageUrl'] = params['image_url']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value

        if 'accept' in params:
            header_params['Accept'] = params['accept']

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json', 'image/gif', 'image/jpg', 'image/png', 'image/svg+xml', 'image/webp'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations/image/cors/{imageUrl}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', None),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_annotation(self, **kwargs):
        """
        Create an annotation
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_annotation(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param AnnotationInputV1 body: Annotation information (required)
        :return: AnnotationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_annotation_with_http_info(**kwargs)
        else:
            (data) = self.create_annotation_with_http_info(**kwargs)
            return data

    def create_annotation_with_http_info(self, **kwargs):
        """
        Create an annotation
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_annotation_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param AnnotationInputV1 body: Annotation information (required)
        :return: AnnotationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_annotation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_annotation`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'AnnotationOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_image(self, **kwargs):
        """
        Delete an image from a journal entry
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_image(id=id_value, file_name=file_name_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the Annotation that uses the image (required)
        :param str file_name: The file name of the image (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_image_with_http_info(**kwargs)
        else:
            (data) = self.delete_image_with_http_info(**kwargs)
            return data

    def delete_image_with_http_info(self, **kwargs):
        """
        Delete an image from a journal entry
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_image_with_http_info(id=id_value, file_name=file_name_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the Annotation that uses the image (required)
        :param str file_name: The file name of the image (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['id', 'file_name']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_image`")
        # verify the required parameter 'file_name' is set
        if ('file_name' not in params) or (params['file_name'] is None):
            raise ValueError("Missing the required parameter `file_name` when calling `delete_image`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']
        if 'file_name' in params:
            path_params['fileName'] = params['file_name']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations/{id}/images/{fileName}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_annotation(self, **kwargs):
        """
        Get an annotation
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_annotation(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the annotation to retrieve (required)
        :return: AnnotationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_annotation_with_http_info(**kwargs)
        else:
            (data) = self.get_annotation_with_http_info(**kwargs)
            return data

    def get_annotation_with_http_info(self, **kwargs):
        """
        Get an annotation
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_annotation_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the annotation to retrieve (required)
        :return: AnnotationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_annotation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_annotation`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'AnnotationOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_annotations(self, **kwargs):
        """
        Get a collection of annotations
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_annotations(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] annotates: A list of item IDs that will filter the annotations returned to only those that annotate the specified items.
        :param str type: The type of annotations to return, either Report or Journal
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: AnnotationListOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationListOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_annotations_with_http_info(**kwargs)
        else:
            (data) = self.get_annotations_with_http_info(**kwargs)
            return data

    def get_annotations_with_http_info(self, **kwargs):
        """
        Get a collection of annotations
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_annotations_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] annotates: A list of item IDs that will filter the annotations returned to only those that annotate the specified items.
        :param str type: The type of annotations to return, either Report or Journal
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: AnnotationListOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationListOutputV1
        """

        all_params = ['annotates', 'type', 'offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_annotations" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'annotates' in params:
            query_params.append(('annotates', params['annotates']))
            collection_formats['annotates'] = 'multi'
        if 'type' in params:
            query_params.append(('type', params['type']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'AnnotationListOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_image(self, **kwargs):
        """
        Get an image for a journal entry
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_image(id=id_value, file_name=file_name_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the Annotation that uses the image (required)
        :param str file_name: The file name of the image (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_image_with_http_info(**kwargs)
        else:
            (data) = self.get_image_with_http_info(**kwargs)
            return data

    def get_image_with_http_info(self, **kwargs):
        """
        Get an image for a journal entry
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_image_with_http_info(id=id_value, file_name=file_name_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the Annotation that uses the image (required)
        :param str file_name: The file name of the image (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        all_params = ['id', 'file_name']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_image`")
        # verify the required parameter 'file_name' is set
        if ('file_name' not in params) or (params['file_name'] is None):
            raise ValueError("Missing the required parameter `file_name` when calling `get_image`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']
        if 'file_name' in params:
            path_params['fileName'] = params['file_name']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json', 'image/gif', 'image/jpg', 'image/png', 'image/svg+xml', 'image/webp'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations/{id}/images/{fileName}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', None),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def migrate_annotation_to_ck_editor(self, **kwargs):
        """
        Mark the annotation as upgraded to CK Editor using the provided HTML
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.migrate_annotation_to_ck_editor(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param MigrateEditorInputV1 body: (required)
        :param str id: The Seeq ID for the report (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.migrate_annotation_to_ck_editor_with_http_info(**kwargs)
        else:
            (data) = self.migrate_annotation_to_ck_editor_with_http_info(**kwargs)
            return data

    def migrate_annotation_to_ck_editor_with_http_info(self, **kwargs):
        """
        Mark the annotation as upgraded to CK Editor using the provided HTML
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.migrate_annotation_to_ck_editor_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param MigrateEditorInputV1 body: (required)
        :param str id: The Seeq ID for the report (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method migrate_annotation_to_ck_editor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `migrate_annotation_to_ck_editor`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `migrate_annotation_to_ck_editor`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations/editorMigration/{id}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def publish_report(self, **kwargs):
        """
        Publish a report so it cannot be changed
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.publish_report(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the report to publish (required)
        :return: AnnotationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.publish_report_with_http_info(**kwargs)
        else:
            (data) = self.publish_report_with_http_info(**kwargs)
            return data

    def publish_report_with_http_info(self, **kwargs):
        """
        Publish a report so it cannot be changed
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.publish_report_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the report to publish (required)
        :return: AnnotationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method publish_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `publish_report`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations/{id}/publish', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'AnnotationOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_annotation(self, **kwargs):
        """
        Update an annotation
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_annotation(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param AnnotationInputV1 body: Annotation input (required)
        :param str id: ID of the annotation to update (required)
        :return: AnnotationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_annotation_with_http_info(**kwargs)
        else:
            (data) = self.update_annotation_with_http_info(**kwargs)
            return data

    def update_annotation_with_http_info(self, **kwargs):
        """
        Update an annotation
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_annotation_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param AnnotationInputV1 body: Annotation input (required)
        :param str id: ID of the annotation to update (required)
        :return: AnnotationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_annotation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_annotation`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_annotation`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations/{id}/update', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'AnnotationOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def upload_image(self, **kwargs):
        """
        Upload an image for a journal entry
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.upload_image(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str file:
        :param str id: The ID of the Annotation that will use the image (required)
        :return: AnnotationImageLinkOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationImageLinkOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.upload_image_with_http_info(**kwargs)
        else:
            (data) = self.upload_image_with_http_info(**kwargs)
            return data

    def upload_image_with_http_info(self, **kwargs):
        """
        Upload an image for a journal entry
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.upload_image_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str file:
        :param str id: The ID of the Annotation that will use the image (required)
        :return: AnnotationImageLinkOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnnotationImageLinkOutputV1
        """

        all_params = ['file', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `upload_image`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/annotations/{id}/images', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'AnnotationImageLinkOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.10-v202311110039
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class AddOnInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'add_on_components': 'str',
        'add_on_identifier': 'str',
        'description': 'str',
        'in_development': 'bool',
        'name': 'str',
        'version_string': 'str'
    }

    attribute_map = {
        'add_on_components': 'addOnComponents',
        'add_on_identifier': 'addOnIdentifier',
        'description': 'description',
        'in_development': 'inDevelopment',
        'name': 'name',
        'version_string': 'versionString'
    }

    def __init__(self, add_on_components=None, add_on_identifier=None, description=None, in_development=False, name=None, version_string=None):
        """
        AddOnInputV1 - a model defined in Swagger
        """

        self._add_on_components = None
        self._add_on_identifier = None
        self._description = None
        self._in_development = None
        self._name = None
        self._version_string = None

        if add_on_components is not None:
          self.add_on_components = add_on_components
        if add_on_identifier is not None:
          self.add_on_identifier = add_on_identifier
        if description is not None:
          self.description = description
        if in_development is not None:
          self.in_development = in_development
        if name is not None:
          self.name = name
        if version_string is not None:
          self.version_string = version_string

    @property
    def add_on_components(self):
        """
        Gets the add_on_components of this AddOnInputV1.
        A stringified representation of the items on this server that comprise this installed add-on.

        :return: The add_on_components of this AddOnInputV1.
        :rtype: str
        """
        return self._add_on_components

    @add_on_components.setter
    def add_on_components(self, add_on_components):
        """
        Sets the add_on_components of this AddOnInputV1.
        A stringified representation of the items on this server that comprise this installed add-on.

        :param add_on_components: The add_on_components of this AddOnInputV1.
        :type: str
        """

        self._add_on_components = add_on_components

    @property
    def add_on_identifier(self):
        """
        Gets the add_on_identifier of this AddOnInputV1.
        The unique identifier associated with this Add-on, shared across all Seeq server instances.

        :return: The add_on_identifier of this AddOnInputV1.
        :rtype: str
        """
        return self._add_on_identifier

    @add_on_identifier.setter
    def add_on_identifier(self, add_on_identifier):
        """
        Sets the add_on_identifier of this AddOnInputV1.
        The unique identifier associated with this Add-on, shared across all Seeq server instances.

        :param add_on_identifier: The add_on_identifier of this AddOnInputV1.
        :type: str
        """
        if add_on_identifier is None:
            raise ValueError("Invalid value for `add_on_identifier`, must not be `None`")

        self._add_on_identifier = add_on_identifier

    @property
    def description(self):
        """
        Gets the description of this AddOnInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :return: The description of this AddOnInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AddOnInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :param description: The description of this AddOnInputV1.
        :type: str
        """

        self._description = description

    @property
    def in_development(self):
        """
        Gets the in_development of this AddOnInputV1.
        Whether this item is in Development Mode, meaning that it is not allowed to be shared with any other users. Non-administrators may only install Add-on Tools in Development Mode. This property may not be altered after creation. Defaults to false.

        :return: The in_development of this AddOnInputV1.
        :rtype: bool
        """
        return self._in_development

    @in_development.setter
    def in_development(self, in_development):
        """
        Sets the in_development of this AddOnInputV1.
        Whether this item is in Development Mode, meaning that it is not allowed to be shared with any other users. Non-administrators may only install Add-on Tools in Development Mode. This property may not be altered after creation. Defaults to false.

        :param in_development: The in_development of this AddOnInputV1.
        :type: bool
        """

        self._in_development = in_development

    @property
    def name(self):
        """
        Gets the name of this AddOnInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :return: The name of this AddOnInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AddOnInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :param name: The name of this AddOnInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def version_string(self):
        """
        Gets the version_string of this AddOnInputV1.
        The version of this add-on. Using a MAJOR.MINOR.PATCH version format is preferred.

        :return: The version_string of this AddOnInputV1.
        :rtype: str
        """
        return self._version_string

    @version_string.setter
    def version_string(self, version_string):
        """
        Sets the version_string of this AddOnInputV1.
        The version of this add-on. Using a MAJOR.MINOR.PATCH version format is preferred.

        :param version_string: The version_string of this AddOnInputV1.
        :type: str
        """

        self._version_string = version_string

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AddOnInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
